==> icinga2_2.2.4.orig.tar.gz: icinga2-2.2.4/lib/cli/variableutility.hpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2015 Icinga Development Team (http://www.icinga.org)    *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#ifndef VARIABLEUTILITY_H
#define VARIABLEUTILITY_H

#include "base/i2-base.hpp"
#include "base/dictionary.hpp"
#include "base/string.hpp"
#include <ostream>

namespace icinga
{

/**
 * @ingroup cli
 */
class VariableUtility
{
public:
	static Value GetVariable(const String& name);
	static void PrintVariables(std::ostream& outfp);

private:
	VariableUtility(void);


};

}

#endif /* VARIABLEUTILITY_H */

==> icinga2_2.4.1.orig.tar.gz: icinga2-2.4.1/lib/cli/variableutility.hpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2015 Icinga Development Team (http://www.icinga.org)    *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#ifndef VARIABLEUTILITY_H
#define VARIABLEUTILITY_H

#include "base/i2-base.hpp"
#include "cli/i2-cli.hpp"
#include "base/dictionary.hpp"
#include "base/string.hpp"
#include <ostream>

namespace icinga
{

/**
 * @ingroup cli
 */
class I2_CLI_API VariableUtility
{
public:
	static Value GetVariable(const String& name);
	static void PrintVariables(std::ostream& outfp);

private:
	VariableUtility(void);

};

}

#endif /* VARIABLEUTILITY_H */
